@@ -67,7 +67,7 @@ uncache = Vectorize(function(target, path, search){
   if(is_file(target) & !is_imported(target = target, 
     cache = cache))
     unquote(target) %>% unlink(recursive = TRUE)
-  for(space in c("objects", "depends", "filemtime"))
+  for(space in c("objects", "depends", "filemtime", "functions"))
     if(target %in% cache$list(namespace = space))
       cache$del(target, namespace = space)
   invisible()
