@@ -4,6 +4,8 @@ run_mclapply = function(config){
 }
 
 worker_mclapply = function(targets, hash_list, config){
-  mclapply(targets, build, hash_list = hash_list,
+  prune_envir(targets = targets, config = config)
+  values = mclapply(targets, build, hash_list = hash_list,
     config = config, mc.cores = config$jobs)
+  assign_to_envir(target = targets, value = values, config = config)
 }
