@@ -59,12 +59,7 @@ parallel_stage = function(graph_remaining_targets, worker,
     should_build(target = target, hash_list = hash_list,
       config = config))
   hash_list = hash_list[build_these]
-  if(length(build_these)){
-    prune_envir(targets = build_these, config = config)
-    values = worker(targets = build_these,
-      hash_list = hash_list, config = config)
-    assign_to_envir(target = build_these, value = values,
-      config = config)
-  }
+  if(length(build_these))
+    worker(targets = build_these, hash_list = hash_list, config = config)
   delete_vertices(graph_remaining_targets, v = candidates)
 }
