@@ -26,8 +26,8 @@ test_that("responses to imported file", {
   # actually change file
   saveRDS(2:10, "input.rds")
   testrun(config)
-  expect_equal(justbuilt(config), c("'intermediatefile.rds'",
-    "combined", "final", "myinput", "nextone"))
+  expect_equal(justbuilt(config), sort(c("'intermediatefile.rds'",
+    "combined", "final", "myinput", "nextone")))
   expect_false(length(final0) == length(readd(final, search = FALSE)))
   dclean()
 })
